#
# Copyright (c) 2008-2017 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.component.location.interfaces import IViewLocationSettings
from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION
from pyams_content.shared.view.interfaces import IWfView
from pyams_form.interfaces.form import IWidgetForm, IInnerSubForm, IUncheckedEditFormButtons
from pyams_skin.interfaces import IInnerPage, IPageHeader
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer
from z3c.form.interfaces import INPUT_MODE

# import packages
from pyams_content.shared.common.zmi import WfSharedContentHeaderAdapter
from pyams_form.form import AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.menu import MenuItem
from pyams_utils.adapter import adapter_config
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminEditForm, InnerAdminEditForm
from pyramid.view import view_config
from z3c.form import button, field
from zope.interface import Interface, implementer

from onf_website import _


@viewlet_config(name='location.menu', context=IWfView, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=VIEW_SYSTEM_PERMISSION, weight=300)
class LocationMenu(MenuItem):
    """Location menu"""

    label = _("Location...")
    icon_class = 'fa-map-marker'
    url = '#location.html'


@pagelet_config(name='location.html', context=IWfView, layer=IPyAMSLayer, permission=VIEW_SYSTEM_PERMISSION)
@implementer(IWidgetForm, IInnerPage)
class LocationEditForm(AdminEditForm):
    """Location settings edit form"""

    legend = _("View location settings")

    fields = field.Fields(Interface)

    @property
    def buttons(self):
        if self.mode == INPUT_MODE:
            return button.Buttons(IUncheckedEditFormButtons)
        else:
            return button.Buttons(Interface)

    ajax_handler = 'location.json'


@view_config(name='location.json', context=IWfView, request_type=IPyAMSLayer,
             permission=MANAGE_CONTENT_PERMISSION, renderer='json', xhr=True)
class LocationAJAXEditForm(AJAXEditForm, LocationEditForm):
    """Location settings edit form, JSON renderer"""


@adapter_config(name='coordinates', context=(IWfView, IPyAMSLayer, LocationEditForm), provides=IInnerSubForm)
class LocationCoordinatesEditSubform(InnerAdminEditForm):
    """Location coordinates edit form"""

    legend = None
    main_group_legend = _("GPS position")

    fields = field.Fields(IViewLocationSettings).select('select_context_gps_location', 'gps_location',
                                                        'gps_distance', 'gps_area')
    weight = 1


@adapter_config(name='location', context=(IWfView, IPyAMSLayer, LocationEditForm), provides=IInnerSubForm)
class LocationMainEditSubform(InnerAdminEditForm):
    """Location main edit form"""

    legend = None
    main_group_legend = _("Location (forest, city, address)")

    fields = field.Fields(IViewLocationSettings).select('select_context_forests', 'forests',
                                                        'select_context_cities', 'cities')
    weight = 2


@adapter_config(name='insee', context=(IWfView, IPyAMSLayer, LocationEditForm), provides=IInnerSubForm)
class LocationAddressEditSubform(InnerAdminEditForm):
    """Location address edit form"""

    legend = None
    main_group_legend = _("Administrative level (country, department)")

    fields = field.Fields(IViewLocationSettings).select('select_context_departments', 'departments',
                                                        'select_context_countries', 'countries')
    weight = 3


@adapter_config(name='forests', context=(IWfView, IPyAMSLayer, LocationEditForm), provides=IInnerSubForm)
class LocationForestsEditSubform(InnerAdminEditForm):
    """Location forests edit form"""

    legend = None
    main_group_legend = _("ONF organisation")

    fields = field.Fields(IViewLocationSettings).select('select_context_structures', 'structures')
    weight = 4


@adapter_config(context=(IWfView, IAdminLayer, LocationEditForm), provides=IPageHeader)
class LocationHeaderAdapter(WfSharedContentHeaderAdapter):
    """Shared content location header adapter"""

    icon_class = 'fa fa-fw fa-map-marker'
