#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.shared.leisure.interfaces import ILeisureManager, LEISURE_CONTENT_TYPE, ILeisureInfo
from pyams_content.component.theme.interfaces import IThemesManagerTarget
from zope.annotation.interfaces import IAttributeAnnotatable
from zope.component.interfaces import ISite
from zope.lifecycleevent.interfaces import IObjectAddedEvent

# import packages
from onf_website.shared.leisure import Leisure
from pyams_content.shared.common.types import TypedSharedTool
from pyams_utils.traversing import get_parent
from pyramid.events import subscriber
from zope.interface import implementer


@implementer(ILeisureManager, IThemesManagerTarget, IAttributeAnnotatable)
class LeisureManager(TypedSharedTool):
    """Leisure manager class"""

    shared_content_type = LEISURE_CONTENT_TYPE
    shared_content_factory = Leisure

    shared_content_types_fields = ILeisureInfo


@subscriber(IObjectAddedEvent, context_selector=ILeisureManager)
def handle_added_imagemaps_manager(event):
    """Register leisures manager when added"""
    site = get_parent(event.newParent, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, ILeisureManager)
